@@ -5,7 +5,7 @@
 //! [![MIT licensed](https://img.shields.io/badge/license-MIT-blue.svg)](./LICENSE)
 //! [![Crates.io](https://img.shields.io/crates/v/bevy_life.svg)](https://crates.io/crates/bevy_life)
 //! [![aragog](https://docs.rs/bevy_life/badge.svg)](https://docs.rs/bevy_life)
-//! [![dependency status](https://deps.rs/crate/bevy_life/0.2.0/status.svg)](https://deps.rs/crate/bevy_life)
+//! [![dependency status](https://deps.rs/crate/bevy_life/0.2.1/status.svg)](https://deps.rs/crate/bevy_life)
 //!
 //! `bevy_life` is a generic plugin for [cellular automaton](https://en.wikipedia.org/wiki/Cellular_automaton).
 //! From the classic 2D [Conway's game of life](https://en.wikipedia.org/wiki/Conway%27s_Game_of_Life) to [WireWorld](https://en.wikipedia.org/wiki/Wireworld) and 3D rules, the plugin is completely generic and dynamic.
@@ -57,8 +57,8 @@
 //!   - `NeumannCell3d` (cube cell with 6 neighbors)
 //!   - plugin presets: `GameOfLife3dPlugin`, `ImmigrationGame3dPlugin`, `RainbowGame3dPlugin`, `WireWorld3dPlugin`, `CyclicAutomaton3dPlugin`
 //! - `auto-coloring` (Example or debug purpose):
-//!   - Enables `CellStateMaterials2d` (if `2D`) and `CellStateMaterials3d` (if `3D`) types to contain material handles
-//!   - The `CellState` type now requires to build either of the previous type (according to 2D/3D feature gates)
+//!   - Enables `CellStateMaterials` resource to contain material handles
+//!   - The `CellState` type now requires to build a `CellStateMaterials`
 //!   - All `CellState` components with materials will be colored according to their type.
 //!
 //! ## Disclaimer
@@ -175,12 +175,16 @@ impl<C: Cell + Component + Debug, S: CellState + Component + Debug, const BATCH_
             #[cfg(feature = "2D")]
             {
                 app.add_startup_system(Self::setup_materials::<ColorMaterial>.system());
-                app.add_system(systems::coloring::color_states::<S, ColorMaterial>.system());
+                app.add_system(
+                    systems::coloring::color_states::<S, ColorMaterial, BATCH_SIZE>.system(),
+                );
             }
             #[cfg(feature = "3D")]
             {
                 app.add_startup_system(Self::setup_materials::<StandardMaterial>.system());
-                app.add_system(systems::coloring::color_states::<S, StandardMaterial>.system());
+                app.add_system(
+                    systems::coloring::color_states::<S, StandardMaterial, BATCH_SIZE>.system(),
+                );
             }
         }
     }
